==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr_HR">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr_HR">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
